==> upload-api-client-internal-2.55.0.tgz: package/src/services/CachingService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { CacheInvalidation } from "../models/CacheInvalidation";
import type { UnionAllFields_CachePolicy_null_ } from "../models/UnionAllFields_CachePolicy_null_";
import { request as __request } from "../core/request";

export class CachingService {
  /**
   * Creates a new public or secret API key for the account.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async setDefaultCachePolicy(
    accountId: AccountId,
    requestBody: UnionAllFields_CachePolicy_null_
  ): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/caching/default_policy`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Creates a new public or secret API key for the account.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async createInvalidation(accountId: AccountId, requestBody: CacheInvalidation): Promise<any> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/caching/invalidations`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.64.0.tgz: package/src/services/CachingService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { CacheInvalidation } from "../models/CacheInvalidation";
import type { PartialCachePolicy } from "../models/PartialCachePolicy";
import { request as __request } from "../core/request";

export class CachingService {
  /**
   * Creates a new public or secret API key for the account.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async setDefaultCachePolicy(accountId: AccountId, requestBody: PartialCachePolicy): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/caching/default_policy`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Creates a new public or secret API key for the account.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async createInvalidation(accountId: AccountId, requestBody: CacheInvalidation): Promise<any> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/caching/invalidations`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
